@@ -29,7 +29,7 @@ double c_quantile(double* data, const int n, const double quantile) {
     std::nth_element(data, right_elem, data_end);
     return(*right_elem);
   } else {
-    // No guarantee that 2nd nth_element call will preserve order such that the pointer used by the 1st call still points to the same thing.
+    // No guarantee that 2nd nth_element call will preserve order such that the pointer used by the 1st call still points to the same thing; so store the result before calling nth_element again.
     std::nth_element(data, left_elem, data_end);
     const double left = *left_elem;
     if(h == 0) {
@@ -42,47 +42,33 @@ double c_quantile(double* data, const int n, const double quantile) {
   }
 }
 
-/*
-  install.packages("climdex.pcic_0.1-1.tar.gz")
-  source("/home/data/projects/cbt_cacci/code/create_climdex_data.r")
-  load("/home/bronaugh/climdex.source.data.Rsave")
-  tree.var.leaves <- tree.filled.in.flat[["20c3m_ncep_crcm"]]
-  calendar <- attr(tree.var.leaves$pr, "calendar")
-  origin <- as.PCICt(as.character(attr(tree.var.leaves$pr, "origin")), calendar)
-  dates <- .PCICt(floor(attr(tree.var.leaves$pr, "time")) * 86400 + as.numeric(origin), calendar)
-  Rprof()
-  d <- compute.climdex.vars(dates, tree.var.leaves$tasmin[1:10,], tree.var.leaves$tasmax[1:10,], tree.var.leaves$pr[1:10,], calendar)
- */
-
 extern "C" {
   // Expects data in date sequence
   //void running_quantile_windowed_365day(const double* data, double* quantiles, const int* n, const double* q, const int* data_length, const int* num_quantiles) {
   SEXP running_quantile_windowed(SEXP data, SEXP n, SEXP q, SEXP dpy) {
-
-    // Coerce data into vectors of appropriate types
-    //PROTECT(data = coerceVector(data, REALSXP));
-    //PROTECT(q = coerceVector(q, REALSXP));
     PROTECT(n = coerceVector(n, INTSXP));
     PROTECT(dpy = coerceVector(dpy, INTSXP));
     
     const int win_size = INTEGER(n)[0];
     
-    const int win_border = floor(win_size / 2);
+    // Implicit pseudo-floor (nearest number to zero) by integer division
+    const int win_border = win_size / 2;
     const int true_data_length = length(data) - 2 * win_border;
     const int days_per_year = INTEGER(dpy)[0];
-    const int num_years = ceil(true_data_length / days_per_year);
+    const int num_years = (int)ceil((double)true_data_length / (double)days_per_year);
     const int repeated_data_size = num_years * (days_per_year + 2 * win_border);
     const int nq = length(q);
     const double* q_ptr = REAL(q);
     const double* data_ptr = REAL(data);
 
     SEXP quantiles = allocVector(REALSXP, nq * days_per_year);
-    //PROTECT(quantiles = allocVector(REALSXP, length(q) * days_per_year));
     double* quantiles_ptr = REAL(quantiles);
 
     // This data will be 2 dimensional, row major, with the major dimension being the day of the year
     double* buf = new double[num_years * win_size];
-    
+
+    // Comment for preservation of sanity...
+    // The input data does not stay on day 'day'; it starts on day 'day' - win_border. This gets around the problem of an off-by-two error.
     for(int day = 0; day < days_per_year; ++day) {
       int count = 0;
       // Fill buffer with data with NA removed
